generated files are a nono in cvs
[privoxy.git] / cgi.c
diff --git a/cgi.c b/cgi.c
index 94a4ea1..f63cca3 100644 (file)
--- a/cgi.c
+++ b/cgi.c
@@ -1,4 +1,4 @@
-const char cgi_rcs[] = "$Id: cgi.c,v 1.45 2002/03/06 22:54:35 jongfoster Exp $";
+const char cgi_rcs[] = "$Id: cgi.c,v 1.52 2002/03/24 15:23:33 jongfoster Exp $";
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/cgi.c,v $
@@ -12,7 +12,7 @@ const char cgi_rcs[] = "$Id: cgi.c,v 1.45 2002/03/06 22:54:35 jongfoster Exp $";
  * 
  *
  * Copyright   :  Written by and Copyright (C) 2001 the SourceForge
- *                IJBSWA team.  http://ijbswa.sourceforge.net
+ *                Privoxy team.  http://ijbswa.sourceforge.net
  *
  *                Based on the Internet Junkbuster originally written
  *                by and Copyright (C) 1997 Anonymous Coders and 
@@ -38,6 +38,34 @@ const char cgi_rcs[] = "$Id: cgi.c,v 1.45 2002/03/06 22:54:35 jongfoster Exp $";
  *
  * Revisions   :
  *    $Log: cgi.c,v $
+ *    Revision 1.52  2002/03/24 15:23:33  jongfoster
+ *    Name changes
+ *
+ *    Revision 1.51  2002/03/24 13:25:43  swa
+ *    name change related issues
+ *
+ *    Revision 1.50  2002/03/16 23:54:06  jongfoster
+ *    Adding graceful termination feature, to help look for memory leaks.
+ *    If you enable this (which, by design, has to be done by hand
+ *    editing config.h) and then go to http://i.j.b/die, then the program
+ *    will exit cleanly after the *next* request.  It should free all the
+ *    memory that was used.
+ *
+ *    Revision 1.49  2002/03/13 00:27:04  jongfoster
+ *    Killing warnings
+ *
+ *    Revision 1.48  2002/03/08 17:47:07  jongfoster
+ *    Adding comments
+ *
+ *    Revision 1.47  2002/03/08 16:41:33  oes
+ *    Added GIF images again
+ *
+ *    Revision 1.46  2002/03/07 03:48:38  oes
+ *     - Changed built-in images from GIF to PNG
+ *       (with regard to Unisys patent issue)
+ *     - Added a 4x4 pattern PNG which is less intrusive
+ *       than the logo but also clearly marks the deleted banners
+ *
  *    Revision 1.45  2002/03/06 22:54:35  jongfoster
  *    Automated function-comment nitpicking.
  *
@@ -317,7 +345,12 @@ const char cgi_h_rcs[] = CGI_H_VERSION;
 static const struct cgi_dispatcher cgi_dispatchers[] = {
    { "",
          cgi_default,
-         "Junkbuster main page" },
+         "Privoxy main page" },
+#ifdef FEATURE_GRACEFUL_TERMINATION
+   { "die", 
+         cgi_die,  
+         "<b>Shut down</b> - <font color=red size='+1'>Do not deploy this build in a production environment, this is a one click Denial Of Service attack!!!</font>" }, 
+#endif
    { "show-status", 
          cgi_show_status,  
          "Show information about the current configuration" }, 
@@ -332,7 +365,7 @@ static const struct cgi_dispatcher cgi_dispatchers[] = {
          "Show which actions apply to a URL and why"  },
    { "toggle",
          cgi_toggle, 
-         "Toggle JunkBuster on or off" },
+         "Toggle Privoxy on or off" },
 #ifdef FEATURE_CGI_EDIT_ACTIONS
    { "edit-actions",
          cgi_edit_actions, 
@@ -402,10 +435,10 @@ static const struct cgi_dispatcher cgi_dispatchers[] = {
          NULL /* Sends a robots.txt file to tell robots to go away. */ }, 
    { "send-banner",
          cgi_send_banner, 
-         NULL /* Send a built-in png image */ },
+         NULL /* Send a built-in image */ },
    { "t",
-         cgi_transparent_png
-         NULL /* Send a transparent png (short name) */ },
+         cgi_transparent_image
+         NULL /* Send a transparent image (short name) */ },
    { NULL, /* NULL Indicates end of list and default page */
          cgi_error_404,
          NULL /* Unknown CGI page */ }
@@ -415,8 +448,14 @@ static const struct cgi_dispatcher cgi_dispatchers[] = {
 /*
  * Bulit-in images for ad replacement
  *
- * Hint: You can encode your own PNGs like this:
- * cat yourfile.png | perl -e 'while (read STDIN, $c, 1) { printf("\\%.3o", unpack("C", $c)); }'
+ * Hint: You can encode your own images like this:
+ * cat your-image | perl -e 'while (read STDIN, $c, 1) { printf("\\%.3o", unpack("C", $c)); }'
+ */
+
+#ifdef FEATURE_NO_GIFS
+
+/*
+ * "Junkbuster" logo, as a PNG.
  */
 const char image_logo_data[] =
    "\211\120\116\107\015\012\032\012\000\000\000\015\111\110\104"
@@ -434,8 +473,9 @@ const char image_logo_data[] =
    "\300\000\000\002\127\040\324\250\204\044\102\000\000\000\000"
    "\111\105\116\104\256\102\140\202";
 
-const size_t image_logo_length = sizeof(image_logo_data) - 1;
-
+/*
+ * Checkerboard pattern, as a PNG.
+ */
 const char image_pattern_data[] =
    "\211\120\116\107\015\012\032\012\000\000\000\015\111\110\104"
    "\122\000\000\000\004\000\000\000\004\010\002\000\000\000\046"
@@ -445,18 +485,56 @@ const char image_pattern_data[] =
    "\304\011\006\234\062\000\125\200\052\251\125\174\360\223\000"
    "\000\000\000\111\105\116\104\256\102\140\202";
 
-const size_t image_pattern_length = sizeof(image_pattern_data) - 1;
+/*
+ * 1x1 transparant PNG.
+ */
+const char image_blank_data[] =
+ "\211\120\116\107\015\012\032\012\000\000\000\015\111\110\104\122"
+ "\000\000\000\004\000\000\000\004\010\006\000\000\000\251\361\236"
+ "\176\000\000\000\007\164\111\115\105\007\322\003\013\020\073\070"
+ "\013\025\036\203\000\000\000\011\160\110\131\163\000\000\013\022"
+ "\000\000\013\022\001\322\335\176\374\000\000\000\004\147\101\115"
+ "\101\000\000\261\217\013\374\141\005\000\000\000\033\111\104\101"
+ "\124\170\332\143\070\161\342\304\207\377\377\377\347\302\150\006"
+ "\144\016\210\146\040\250\002\000\042\305\065\221\270\027\131\110"
+ "\000\000\000\000\111\105\116\104\256\102\140\202";
+#else
+
+/*
+ * "Junkbuster" logo, as a GIF.
+ */
+const char image_logo_data[] =
+   "GIF89aD\000\013\000\360\000\000\000\000\000\377\377\377!"
+   "\371\004\001\000\000\001\000,\000\000\000\000D\000\013\000"
+   "\000\002a\214\217\251\313\355\277\000\200G&K\025\316hC\037"
+   "\200\234\230Y\2309\235S\230\266\206\372J\253<\3131\253\271"
+   "\270\215\342\254\013\203\371\202\264\334P\207\332\020o\266"
+   "N\215I\332=\211\312\3513\266:\026AK)\364\370\365aobr\305"
+   "\372\003S\275\274k2\354\254z\347?\335\274x\306^9\374\276"
+   "\037Q\000\000;";
+
+/*
+ * Checkerboard pattern, as a GIF.
+ */
+const char image_pattern_data[] =
+   "\107\111\106\070\071\141\004\000\004\000\200\000\000\310\310"
+   "\310\377\377\377\041\376\025\111\040\165\163\145\144\040\164"
+   "\157\040\142\145\040\141\040\142\141\156\156\145\162\000\054"
+   "\000\000\000\000\004\000\004\000\000\002\005\104\174\147\270"
+   "\005\000\073";
 
+/*
+ * 1x1 transparant GIF.
+ */
 const char image_blank_data[] =
-   "\211\120\116\107\015\012\032\012\000\000\000\015\111\110\104"
-   "\122\000\000\000\002\000\000\000\002\010\002\000\000\000\375"
-   "\324\232\163\000\000\000\006\142\113\107\104\000\310\000\310"
-   "\000\310\052\045\225\037\000\000\000\027\111\104\101\124\170"
-   "\332\143\374\377\377\377\311\223\047\031\116\234\070\361\377"
-   "\377\177\000\112\335\012\257\162\103\306\335\000\000\000\000"
-   "\111\105\116\104\256\102\140\202o";
+   "GIF89a\001\000\001\000\200\000\000\377\377\377\000\000"
+   "\000!\371\004\001\000\000\000\000,\000\000\000\000\001"
+   "\000\001\000\000\002\002D\001\000;";
+#endif
 
-const size_t image_blank_length = sizeof(image_blank_data) - 1;
+const size_t image_logo_length    = sizeof(image_logo_data) - 1;
+const size_t image_pattern_length = sizeof(image_pattern_data) - 1;
+const size_t image_blank_length   = sizeof(image_blank_data) - 1;
 
 
 static struct http_response cgi_error_memory_response[1];
@@ -608,7 +686,8 @@ static struct http_response *dispatch_known_cgi(struct client_state * csp,
                             csp->ip_addr_str, csp->http->cmd); 
 
    /* Find and start the right CGI function*/
-   for (d = cgi_dispatchers; FOREVER; d++)
+   d = cgi_dispatchers;
+   for (;;)
    {
       if ((d->name == NULL) || (strcmp(path_copy, d->name) == 0))
       {
@@ -631,6 +710,7 @@ static struct http_response *dispatch_known_cgi(struct client_state * csp,
             return cgi_error_memory();
          }
       }
+      d++;
    }
 }
 
@@ -784,15 +864,15 @@ void cgi_init_error_messages(void)
 {
    memset(cgi_error_memory_response, '\0', sizeof(*cgi_error_memory_response));
    cgi_error_memory_response->head =
-      "HTTP/1.0 500 Internal JunkBuster Proxy Error\r\n"
+      "HTTP/1.0 500 Internal Privoxy Error\r\n"
       "Content-Type: text/html\r\n"
       "\r\n";
    cgi_error_memory_response->body =
       "<html>\r\n"
-      "<head><title>500 Internal JunkBuster Proxy Error</title></head>\r\n"
+      "<head><title>500 Internal Privoxy Error</title></head>\r\n"
       "<body>\r\n"
-      "<h1>500 Internal JunkBuster Proxy Error</h1>\r\n"
-      "<p>JunkBuster <b>ran out of memory</b> while processing your request.</p>\r\n"
+      "<h1>500 Internal Privoxy Error</h1>\r\n"
+      "<p>Privoxy <b>ran out of memory</b> while processing your request.</p>\r\n"
       "<p>Please contact your proxy administrator, or try again later</p>\r\n"
       "</body>\r\n"
       "</html>\r\n";
@@ -854,13 +934,13 @@ jb_err cgi_error_no_template(struct client_state *csp,
                              const char *template_name)
 {
    static const char status[] =
-      "500 Internal JunkBuster Proxy Error";
+      "500 Internal Privoxy Error";
    static const char body_prefix[] =
       "<html>\r\n"
-      "<head><title>500 Internal JunkBuster Proxy Error</title></head>\r\n"
+      "<head><title>500 Internal Privoxy Error</title></head>\r\n"
       "<body>\r\n"
-      "<h1>500 Internal JunkBuster Proxy Error</h1>\r\n"
-      "<p>JunkBuster encountered an error while processing your request:</p>\r\n"
+      "<h1>500 Internal Privoxy Error</h1>\r\n"
+      "<p>Privoxy encountered an error while processing your request:</p>\r\n"
       "<p><b>Could not load template file <code>";
    static const char body_suffix[] =
       "</code></b></p>\r\n"
@@ -868,10 +948,10 @@ jb_err cgi_error_no_template(struct client_state *csp,
       "<p>If you are the proxy administrator, please put the required file "
       "in the <code><i>(confdir)</i>/templates</code> directory.  The "
       "location of the <code><i>(confdir)</i></code> directory "
-      "is specified in the main JunkBuster <code>config</code> "
-      "file.  (It's typically the JunkBuster install directory"
+      "is specified in the main Privoxy <code>config</code> "
+      "file.  (It's typically the Privoxy install directory"
 #ifndef _WIN32
-      ", or <code>/etc/junkbuster/</code>"
+      ", or <code>/etc/privoxy/</code>"
 #endif /* ndef _WIN32 */
       ").</p>\r\n"
       "</body>\r\n"
@@ -1064,7 +1144,7 @@ struct http_response *finish_http_response(struct http_response *rsp)
    {
       /*
        * Set Expires to about 10 min into the future so it'll get reloaded
* occasionally, e.g. if IJB gets upgraded.
        */
 
       if (!err)
@@ -1064,7 +1144,7 @@ struct http_response *finish_http_response(struct http_response *rsp)
       /*
        * Set Expires to about 10 min into the future so it'll get reloaded
-       * occasionally, e.g. if IJB gets upgraded.
+       * occasionally, e.g. if Privoxy gets upgraded.
        */
 